# pyqttoolkit
# Copyright (C) 2018-2019, Simmovation Ltd.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software Foundation,
# Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
from PyQt5.QtWidgets import QStyleOption, QStyle
from PyQt5.QtGui import QPainter

opt = QStyleOption()

def make_styleable(cls):
    global opt
    class Styleable(cls):
        def __init__(self, *args, **kwargs):
            super().__init__(*args, **kwargs)
            self._painter = None
        
        def paintEvent(self, event):
            self._painter = QPainter(self)
            opt.initFrom(self)
            self.style().drawPrimitive(QStyle.PE_Widget, opt, self._painter, self)
            self._painter.end()
            return super().paintEvent(event)

    return Styleable

